@@ -254,7 +254,3 @@ def generate_psf(s: PSFConfig) -> np.ndarray:
     I1 = Ix2 + Iy2 + Iz2
 
     return np.moveaxis(I1, 2, 0).astype(np.float64)
-
-
-class AprilVersion(PSFGenerator):
-    pass
