@@ -1,6 +1,6 @@
 from magicgui import magic_factory, magicgui
 from faser.generators.base import Aberration, PSFConfig, Mode, Polarization
-from faser.generators.vectorial.stephane import StephanePSFGenerator
+from faser.generators.vectorial.stephane import generate_psf
 import numpy as np
 import napari
 from qtpy.QtWidgets import QHBoxLayout, QPushButton, QWidget
@@ -27,7 +27,7 @@ viewer = None
     trefoil_h=slider,
     spherical=slider,
 )
-def generate_psf(
+def generate_psf_gui(
     viewer: napari.Viewer,
     Nx=32,
     Ny=32,
@@ -77,5 +77,5 @@ def generate_psf(
         LfocalZ=LfocalZ * 1e-6,
     )
 
-    psf = StephanePSFGenerator(config).generate()
+    psf = generate_psf(config)
     return viewer.add_image(psf, name=f"PSF {config.aberration} ")
